@@ -8,73 +8,74 @@ setGeneric("handleNA", function(umf, ...) standardGeneric("handleNA"))
 # unmarkedFrame
 
 setMethod("getDesign", "unmarkedFrame",
-    function(umf, formula, na.rm=TRUE) 
+    function(umf, formula, na.rm=TRUE)
 {
-	detformula <- as.formula(formula[[2]])
-	stateformula <- as.formula(paste("~", formula[3], sep=""))
-	detVars <- all.vars(detformula)
-	
-	M <- numSites(umf)
-	R <- obsNum(umf)
-	
-	## Compute state design matrix
-	if(is.null(siteCovs(umf))) {
-		siteCovs <- data.frame(placeHolder = rep(1, M))
-	} else {
-		siteCovs <- siteCovs(umf)
-	}
-	X.mf <- model.frame(stateformula, siteCovs, na.action = NULL)
-	X <- model.matrix(stateformula, X.mf)
-        X.offset <- as.vector(model.offset(X.mf))
-        if (!is.null(X.offset)) {
-          X.offset[is.na(X.offset)] <- 0
-        }
+    detformula <- as.formula(formula[[2]])
+    stateformula <- as.formula(paste("~", formula[3], sep=""))
+    detVars <- all.vars(detformula)
 
-	## Compute detection design matrix
-	if(is.null(obsCovs(umf))) {
-		obsCovs <- data.frame(placeHolder = rep(1, M*R))
-	} else {
-		obsCovs <- obsCovs(umf)
-	}
-	
-	## Record future column names for obsCovs
-	colNames <- c(colnames(obsCovs), colnames(siteCovs))
-	
-	## add site Covariates at observation-level
-	obsCovs <- cbind(obsCovs, siteCovs[rep(1:M, each = R),])
-	colnames(obsCovs) <- colNames
-	
-	## add observation number if not present
-	if(!("obsNum" %in% names(obsCovs))) {
-		obsCovs <- cbind(obsCovs, obsNum = as.factor(rep(1:R, M)))
-	}
-	
-	V.mf <- model.frame(detformula, obsCovs, na.action = NULL)
-	V <- model.matrix(detformula, V.mf)
-        V.offset <- as.vector(model.offset(V.mf))
-	if (!is.null(V.offset)) {
-          V.offset[is.na(V.offset)] <- 0
-        }
+    M <- numSites(umf)
+    R <- obsNum(umf)
 
-	if (na.rm) {
-          out <- handleNA(umf, X, X.offset, V, V.offset)
-          y <- out$y
-          X <- out$X
-          X.offset <- out$X.offset
-          V <- out$V
-          V.offset <- out$V.offset
-          removed.sites <- out$removed.sites
-        } else {
-          y=getY(umf)
-          removed.sites=integer(0)
-        }
+    ## Compute state design matrix
+    if(is.null(siteCovs(umf))) {
+        siteCovs <- data.frame(placeHolder = rep(1, M))
+    } else {
+        siteCovs <- siteCovs(umf)
+    }
+    X.mf <- model.frame(stateformula, siteCovs, na.action = NULL)
+    X <- model.matrix(stateformula, X.mf)
+    X.offset <- as.vector(model.offset(X.mf))
+    if (!is.null(X.offset)) {
+        X.offset[is.na(X.offset)] <- 0
+    }
 
-    return(list(y = y, X = X, X.offset = X.offset, V = V, 
-        V.offset = V.offset, removed.sites = removed.sites))
-	})
+    ## Compute detection design matrix
+    if(is.null(obsCovs(umf))) {
+        obsCovs <- data.frame(placeHolder = rep(1, M*R))
+    } else {
+        obsCovs <- obsCovs(umf)
+    }
+
+    ## Record future column names for obsCovs
+    colNames <- c(colnames(obsCovs), colnames(siteCovs))
+
+    ## add site Covariates at observation-level
+    obsCovs <- cbind(obsCovs, siteCovs[rep(1:M, each = R),])
+    colnames(obsCovs) <- colNames
+
+    ## add observation number if not present
+    if(!("obsNum" %in% names(obsCovs))) {
+        obsCovs <- cbind(obsCovs, obsNum = as.factor(rep(1:R, M)))
+    }
+
+    V.mf <- model.frame(detformula, obsCovs, na.action = NULL)
+    V <- model.matrix(detformula, V.mf)
+    V.offset <- as.vector(model.offset(V.mf))
+    if (!is.null(V.offset)) {
+        V.offset[is.na(V.offset)] <- 0
+    }
+
+    if (na.rm) {
+        out <- handleNA(umf, X, X.offset, V, V.offset)
+        y <- out$y
+        X <- out$X
+        X.offset <- out$X.offset
+        V <- out$V
+        V.offset <- out$V.offset
+        removed.sites <- out$removed.sites
+    } else {
+        y=getY(umf)
+        removed.sites=integer(0)
+    }
+
+    return(list(y = y, X = X, X.offset = X.offset, V = V,
+                V.offset = V.offset, removed.sites = removed.sites))
+})
 
 
-setMethod("handleNA", "unmarkedFrame", function(umf, X, X.offset, V, V.offset) 
+setMethod("handleNA", "unmarkedFrame",
+          function(umf, X, X.offset, V, V.offset)
 {
     obsToY <- obsToY(umf)
     if(is.null(obsToY)) stop("obsToY cannot be NULL to clean data.")
@@ -121,37 +122,37 @@ setMethod("handleNA", "unmarkedFrame", function(umf, X, X.offset, V, V.offset)
         warning(paste(num.to.remove,"sites have been discarded because of missing data."), call. = FALSE)
         }
 
-    list(y = y, X = X, X.offset = X.offset, V = V, V.offset = V.offset, 
+    list(y = y, X = X, X.offset = X.offset, V = V, V.offset = V.offset,
         removed.sites = which(sites.to.remove))
     })
-    
-    
-
-
-# UnmarkedMultFrame    
 
 
 
 
-setMethod("getDesign", "unmarkedMultFrame", 
+# UnmarkedMultFrame
+
+
+
+
+setMethod("getDesign", "unmarkedMultFrame",
     function(umf, formula, na.rm = TRUE) {
 
     aschar1 <- as.character(formula)
     aschar2 <- as.character(formula[[2]])
-    aschar3 <- as.character(formula[[2]][[2]])    
+    aschar3 <- as.character(formula[[2]][[2]])
 
     detformula <- as.formula(paste(aschar1[1], aschar1[3]))
     epsformula <- as.formula(paste(aschar2[1], aschar2[3]))
     gamformula <- as.formula(paste(aschar3[1], aschar3[3]))
     psiformula <- as.formula(formula[[2]][[2]][[2]])
-    
+
     detVars <- all.vars(detformula)
-  
+
     M <- numSites(umf)
     R <- obsNum(umf)
     nY <- umf@numPrimary
     J <- R / nY
-  
+
     ## Compute phi design matrices
     if(is.null(umf@yearlySiteCovs)) {
         yearlySiteCovs <- data.frame(placeHolder = rep(1, M*nY))
@@ -163,7 +164,7 @@ setMethod("getDesign", "unmarkedMultFrame",
         sC <- umf@siteCovs[rep(1:M, each = nY),,drop=FALSE]
         yearlySiteCovs <- cbind(yearlySiteCovs, sC)
         }
-  
+
     ## Compute site-level design matrix for psi
     if(is.null(siteCovs(umf)))
         siteCovs <- data.frame(placeHolder = rep(1, M))
@@ -175,7 +176,7 @@ setMethod("getDesign", "unmarkedMultFrame",
         stop("offsets not currently allowed in colext", call.=FALSE)
     W <- model.matrix(psiformula, W.mf)
 
-  
+
     ## Compute detection design matrix
     if(is.null(obsCovs(umf)))
         obsCovs <- data.frame(placeHolder = rep(1, M*R))
@@ -186,16 +187,16 @@ setMethod("getDesign", "unmarkedMultFrame",
     cnames <- c(colnames(obsCovs), colnames(yearlySiteCovs))
     obsCovs <- cbind(obsCovs, yearlySiteCovs[rep(1:(M*nY), each = J),])
     colnames(obsCovs) <- cnames
-	
+
     ## add observation number if not present
     if(!("obsNum" %in% names(obsCovs)))
         obsCovs <- cbind(obsCovs, obsNum = as.factor(rep(1:R, M)))
-	
+
     V.mf <- model.frame(detformula, obsCovs, na.action = NULL)
     if(!is.null(model.offset(V.mf)))
         stop("offsets not currently allowed in colext", call.=FALSE)
     V <- model.matrix(detformula, V.mf)
-    
+
     ## in order to drop factor levels that only appear in last year,
     ## replace last year with NAs and use drop=TRUE
     yearlySiteCovs[seq(nY,M*nY,by=nY),] <- NA
@@ -210,15 +211,15 @@ setMethod("getDesign", "unmarkedMultFrame",
     if(!is.null(model.offset(X.mf.eps)))
         stop("offsets not currently allowed in colext", call.=FALSE)
     X.eps <- model.matrix(epsformula, X.mf.eps)
-    
-	
+
+
     if(na.rm)
         out <- handleNA(umf, X.gam, X.eps, W, V)
     else
-        out <- list(y=getY(umf), X.gam=X.gam, X.eps=X.eps, W=W, V=V, 
+        out <- list(y=getY(umf), X.gam=X.gam, X.eps=X.eps, W=W, V=V,
             removed.sites=integer(0))
 
-    return(list(y = out$y, X.eps = out$X.eps, X.gam = out$X.gam, W = out$W, 
+    return(list(y = out$y, X.eps = out$X.eps, X.gam = out$X.gam, W = out$W,
         V = out$V, removed.sites = out$removed.sites))
 })
 
@@ -227,23 +228,23 @@ setMethod("getDesign", "unmarkedMultFrame",
 
 
 
-setMethod("handleNA", "unmarkedMultFrame", function(umf, X.gam, X.eps, W, V) 
+setMethod("handleNA", "unmarkedMultFrame", function(umf, X.gam, X.eps, W, V)
 {
     obsToY <- obsToY(umf)
     if(is.null(obsToY)) stop("obsToY cannot be NULL to clean data.")
-	
+
     R <- obsNum(umf)
     M <- numSites(umf)
     nY <- umf@numPrimary
     J <- numY(umf) / nY
-	
+
     ## treat both X's and W together
     X <- cbind(X.gam, X.eps, W[rep(1:M, each = nY), ])
 
     X.na <- is.na(X)
     X.na[seq(nY,M*nY,by=nY),] <- FALSE  ## final years are unimportant (not used).
     X.long.na <- X.na[rep(1:(M*nY), each = J),]
-	
+
     V.long.na <- apply(V, 2, function(x) {
         x.mat <- matrix(x, M, R, byrow = TRUE)
         x.mat <- is.na(x.mat)
@@ -252,20 +253,20 @@ setMethod("handleNA", "unmarkedMultFrame", function(umf, X.gam, X.eps, W, V)
 				x.long > 0
         })
     V.long.na <- apply(V.long.na, 1, any)
-	
+
     y.long <- as.vector(t(getY(umf)))
     y.long.na <- is.na(y.long)
-	
+
     covs.na <- apply(cbind(X.long.na, V.long.na), 1, any)
-	
+
     ## are any NA in covs not in y already?
     y.new.na <- covs.na & !y.long.na
-	
+
     if(sum(y.new.na) > 0) {
         y.long[y.new.na] <- NA
         warning("Some observations have been discarded because correspoding covariates were missing.", call. = FALSE)
         }
-	
+
     y <- matrix(y.long, M, numY(umf), byrow = TRUE)
     sites.to.remove <- apply(y, 1, function(x) all(is.na(x)))
     num.to.remove <- sum(sites.to.remove)
@@ -281,88 +282,103 @@ setMethod("handleNA", "unmarkedMultFrame", function(umf, X.gam, X.eps, W, V)
         removed.sites = which(sites.to.remove))
 })
 
-  
+
 
 
 
 
 # pcountOpen
-setMethod("getDesign", "unmarkedFramePCO", 
-    function(umf, formula, na.rm = TRUE) 
+setMethod("getDesign", "unmarkedFramePCO",
+    function(umf, formula, na.rm = TRUE)
 {
     aschar1 <- as.character(formula)
     aschar2 <- as.character(formula[[2]])
-    aschar3 <- as.character(formula[[2]][[2]])    
+    aschar3 <- as.character(formula[[2]][[2]])
 
     pformula <- as.formula(paste(aschar1[1], aschar1[3]))
     omformula <- as.formula(paste(aschar2[1], aschar2[3]))
     gamformula <- as.formula(paste(aschar3[1], aschar3[3]))
     lamformula <- as.formula(formula[[2]][[2]][[2]])
-	
+
     y <- getY(umf)
     M <- nrow(y)
     T <- umf@numPrimary
     J <- ncol(y) / T
     delta <- umf@primaryPeriod
-    
+
     if(is.null(umf@yearlySiteCovs))
         yearlySiteCovs <- data.frame(placeHolder = rep(1, M*T))
     else
         yearlySiteCovs <- umf@yearlySiteCovs
-    
+
     ## add siteCovs in so they can be used as well
     if(!is.null(umf@siteCovs)) {
         sC <- umf@siteCovs[rep(1:M, each = T),,drop=FALSE]
         yearlySiteCovs <- cbind(yearlySiteCovs, sC)
         }
-    
+
     if(is.null(siteCovs(umf)))
-	     siteCovs <- data.frame(placeHolder = rep(1, M))
+        siteCovs <- data.frame(placeHolder = rep(1, M))
     else
-	     siteCovs <- siteCovs(umf)
+        siteCovs <- siteCovs(umf)
 
     Xlam.mf <- model.frame(lamformula, siteCovs, na.action = NULL)
     Xlam <- model.matrix(lamformula, Xlam.mf)
+    Xlam.offset <- as.vector(model.offset(Xlam.mf))
+    if(!is.null(Xlam.offset))
+        Xlam.offset[is.na(Xlam.offset)] <- 0
 
     if(is.null(obsCovs(umf)))
-	     obsCovs <- data.frame(placeHolder = rep(1, M*J*T))
+        obsCovs <- data.frame(placeHolder = rep(1, M*J*T))
     else
-	     obsCovs <- obsCovs(umf)
-	
+        obsCovs <- obsCovs(umf)
+
     colNames <- c(colnames(obsCovs), colnames(yearlySiteCovs))
-	
-	  # Add yearlySiteCovs, which contains siteCovs
+
+    # Add yearlySiteCovs, which contains siteCovs
     obsCovs <- cbind(obsCovs, yearlySiteCovs[rep(1:(M*T), each = J),])
     colnames(obsCovs) <- colNames
-	
+
     if(!("obsNum" %in% names(obsCovs)))
         obsCovs <- cbind(obsCovs, obsNum = as.factor(rep(1:(J*T), M)))
-        
+
     # Ignore last year of data
     transCovs <- yearlySiteCovs[-seq(T, M*T, by=T),,drop=FALSE]
     for(i in 1:ncol(transCovs))
-        if(is.factor(transCovs[,i])) 
+        if(is.factor(transCovs[,i]))
             transCovs[,i] <- factor(transCovs[,i]) # drop unused levels
-	
+
     Xp.mf <- model.frame(pformula, obsCovs, na.action = NULL)
     Xp <- model.matrix(pformula, Xp.mf)
+    Xp.offset <- as.vector(model.offset(Xp.mf))
+    if(!is.null(Xp.offset))
+        Xp.offset[is.na(Xp.offset)] <- 0
     Xgam.mf <- model.frame(gamformula, transCovs, na.action = NULL)
     Xgam <- model.matrix(gamformula, Xgam.mf)
+    Xgam.offset <- as.vector(model.offset(Xgam.mf))
+    if(!is.null(Xgam.offset))
+        Xgam.offset[is.na(Xgam.offset)] <- 0
     Xom.mf <- model.frame(omformula, transCovs, na.action = NULL)
     Xom <- model.matrix(omformula, Xom.mf)
-    
+    Xom.offset <- as.vector(model.offset(Xom.mf))
+    if(!is.null(Xom.offset))
+        Xom.offset[is.na(Xom.offset)] <- 0
+
     # determine if gamma and omega are scalar, vector, or matrix valued
     # Runtime is much faster for scalars and vectors
     Xgo <- cbind(Xgam, Xom)
     getGOdims <- function(x) {
         xm <- matrix(x, M, T-1, byrow=TRUE)
+        anyNA <- apply(is.na(xm), 1, any)
+        xm <- xm[!anyNA,] # This is not 100% safe
+        nSites <- nrow(xm)
         if(all(dim(unique(xm, MARGIN=1)) == c(1, T-1)))
             return("rowvec")
-        else if(all(dim(unique(xm, MARGIN=2)) == c(M, 1)))
+        else if(all(dim(unique(xm, MARGIN=2)) == c(nSites, 1)))
             return("colvec")
         else return("matrix")
         }
-    if(isTRUE(all.equal(gamformula, ~1)) & isTRUE(all.equal(omformula, ~1)))
+    if(isTRUE(all.equal(gamformula,~1)) & isTRUE(all.equal(omformula, ~1)))
         go.dims <- "scalar"
     else {
         go.dims.vec <- apply(Xgo, 2, getGOdims)
@@ -372,93 +388,101 @@ setMethod("getDesign", "unmarkedFramePCO",
             go.dims <- "colvec"
         else
             go.dims <- "matrix"
-        }
-	
+    }
+
     if(na.rm)
-        out <- handleNA(umf, Xlam, Xgam, Xom, Xp, delta)
+        out <- handleNA(umf, Xlam, Xgam, Xom, Xp,
+                        Xlam.offset, Xgam.offset, Xom.offset, Xp.offset,
+                        delta)
     else {   # delta needs to be formatted first
         ya <- array(y, c(M, J, T))
         yna <- apply(is.na(ya), c(1,3), all)
         delta <- formatDelta(delta, yna)
-        out <- list(y=y, Xlam=Xlam, Xgam=Xgam, Xom=Xom, Xp=Xp, 
-            delta=delta, removed.sites=integer(0), go.dims=go.dims)
-        }
-	
-    return(list(y = out$y, Xlam = out$Xlam, Xgam = out$Xgam, Xom = out$Xom, 
-        Xp = out$Xp, delta = out$delta, removed.sites = out$removed.sites, 
-        go.dims = go.dims))
-    })
-    
-  
-    
-    
-    
-    
+        out <- list(y=y, Xlam=Xlam, Xgam=Xgam, Xom=Xom, Xp=Xp,
+                    Xlam.offset=Xlam.offset, Xgam.offset=Xgam.offset,
+                    Xom.offset=Xom.offset, Xp.offset=Xp.offset,
+                    delta=delta, removed.sites=integer(0), go.dims=go.dims)
+    }
+
+    return(list(y = out$y, Xlam = out$Xlam, Xgam = out$Xgam,
+                Xom = out$Xom, Xp = out$Xp,
+                Xlam.offset=Xlam.offset, Xgam.offset=Xgam.offset,
+                Xom.offset=Xom.offset, Xp.offset=Xp.offset,
+                delta = out$delta, removed.sites = out$removed.sites,
+                go.dims = go.dims))
+})
 
 
-setMethod("handleNA", "unmarkedFramePCO", 
-    function(umf, Xlam, Xgam, Xom, Xp, delta) 
+
+
+
+
+
+
+setMethod("handleNA", "unmarkedFramePCO",
+    function(umf, Xlam, Xgam, Xom, Xp, Xlam.offset, Xgam.offset,
+             Xom.offset, Xp.offset, delta)
 {
 	obsToY <- obsToY(umf)
 	if(is.null(obsToY)) stop("obsToY cannot be NULL to clean data.")
 
-	M <- numSites(umf)	
+	M <- numSites(umf)
 	T <- umf@numPrimary
 	y <- getY(umf)
 	J <- ncol(y) / T
 
 	Xlam.long <- Xlam[rep(1:M, each = J*T),]
 	Xlam.long.na <- is.na(Xlam.long)
-	
-	long.na <- function(x) {
-		x.mat <- matrix(x, M, J*T, byrow = TRUE)
-		x.mat <- is.na(x.mat)
-		x.mat <- x.mat %*% obsToY
-		x.long <- as.vector(t(x.mat))
-		x.long > 0
-		}
 
-  o2y2 <- diag(T)
-  o2y2 <- o2y2[-T, -T]
+	long.na <- function(x) {
+            x.mat <- matrix(x, M, J*T, byrow = TRUE)
+            x.mat <- is.na(x.mat)
+            x.mat <- x.mat %*% obsToY
+            x.long <- as.vector(t(x.mat))
+            x.long > 0
+        }
+
+        o2y2 <- diag(T)
+        o2y2 <- o2y2[-T, -T]
 
 	long.na2 <- function(x) {
-		x.mat <- matrix(x, M, T-1, byrow = TRUE)
-		x.mat <- is.na(x.mat)		
-		x.mat <- x.mat %*% o2y2
-		x.long <- as.vector(t(x.mat))
-		x.long > 0
-		}
-	
+            x.mat <- matrix(x, M, T-1, byrow = TRUE)
+            x.mat <- is.na(x.mat)
+            x.mat <- x.mat %*% o2y2
+            x.long <- as.vector(t(x.mat))
+            x.long > 0
+        }
+
 	Xp.long.na <- apply(Xp, 2, long.na)
 	Xp.long.na <- apply(Xp.long.na, 1, any)
-	
-  Xgam.long.na <- apply(Xgam, 2, long.na2)			
-	Xgam.long.na <- apply(Xgam.long.na, 1, any)		
-	Xom.long.na <- apply(Xom, 2, long.na2)			
-	Xom.long.na <- apply(Xom.long.na, 1, any)		
-	
+
+        Xgam.long.na <- apply(Xgam, 2, long.na2)
+	Xgam.long.na <- apply(Xgam.long.na, 1, any)
+	Xom.long.na <- apply(Xom, 2, long.na2)
+	Xom.long.na <- apply(Xom.long.na, 1, any)
+
 	y.long <- as.vector(t(y))
 	y.long.na <- is.na(y.long)
-	
+
 #  delta.long <- as.vector(t(delta))
 #	delta.long.na <- is.na(delta.long)
-	
+
 	covs.na <- apply(cbind(Xlam.long.na, Xp.long.na), 1, any)
 	covs.na2 <- apply(cbind(Xgam.long.na, Xom.long.na), 1, any)
 	covs.na3 <- rep(covs.na2, each=J)
 	# If gamma[1, 1] is NA, remove y[1, 2]
 	#common <- 1:(M*J*(T-1))
-  ignore <- rep(seq(1, M*J*T, by=J*T), each=J) + 0:(J-1)
-  covs.na[-ignore] <- covs.na[-ignore] | covs.na3 
-	
+        ignore <- rep(seq(1, M*J*T, by=J*T), each=J) + 0:(J-1)
+        covs.na[-ignore] <- covs.na[-ignore] | covs.na3
+
 	## are any NA in covs not in y already?
-	y.new.na <- covs.na & !y.long.na      
-	
+	y.new.na <- covs.na & !y.long.na
+
 	if(sum(y.new.na) > 0) {
         y.long[y.new.na] <- NA
         warning("Some observations have been discarded because corresponding covariates were missing.", call. = FALSE)
         }
-	
+
 	y.wide <- matrix(y.long, nrow=M, ncol=J*T, byrow = TRUE)
 #	delta <- matrix(delta.long, nrow=M, ncol=T, byrow = TRUE)
 	sites.to.remove <- apply(y.wide, 1, function(x) all(is.na(x)))
@@ -476,40 +500,52 @@ setMethod("handleNA", "unmarkedFramePCO",
 #      else
 #          return(T-1))
 #  no.go.before.y <- last.y <= last.go
-          
+
 	ya <- array(y.wide, c(M, J, T))
 	yna <- apply(is.na(ya), c(1,3), all)
 	delta <- formatDelta(delta, yna)
-	
+
 	num.to.remove <- sum(sites.to.remove)
 	if(num.to.remove > 0) {
-		y.wide <- y.wide[!sites.to.remove, ,drop = FALSE]
-		Xlam <- Xlam[!sites.to.remove, ,drop = FALSE]
-		Xgam <- Xgam[!sites.to.remove[rep(1:M, each = T-1)], ,drop = FALSE]
-		Xom <- Xom[!sites.to.remove[rep(1:M, each = T-1)], ,drop = FALSE]
-		Xp <- Xp[!sites.to.remove[rep(1:M, each = T)], ,drop = FALSE]
-		delta <- delta[!sites.to.remove, ,drop =FALSE]
-		warning(paste(num.to.remove, "sites have been discarded because of missing data."), call.=FALSE)
+            y.wide <- y.wide[!sites.to.remove, ,drop = FALSE]
+            Xlam <- Xlam[!sites.to.remove, ,drop = FALSE]
+            Xlam.offset <- Xlam.offset[!sites.to.remove]
+            Xgam <- Xgam[!sites.to.remove[rep(1:M, each = T-1)],,
+                         drop = FALSE]
+            Xgam.offset <- Xgam.offset[!sites.to.remove[rep(1:M, each = T-1)],,
+                         drop = FALSE]
+            Xom <- Xom[!sites.to.remove[rep(1:M, each = T-1)],,
+                       drop = FALSE]
+            Xom.offset <- Xom.offset[!sites.to.remove[rep(1:M, each = T-1)],,
+                       drop = FALSE]
+            Xp <- Xp[!sites.to.remove[rep(1:M, each = T)],,
+                     drop = FALSE]
+            Xp.offset <- Xp.offset[!sites.to.remove[rep(1:M, each = T)],,
+                     drop = FALSE]
+            delta <- delta[!sites.to.remove, ,drop =FALSE]
+            warning(paste(num.to.remove, "sites have been discarded because of missing data."), call.=FALSE)
 	}
-	
-	list(y = y.wide, Xlam = Xlam, Xgam = Xgam, Xom = Xom, Xp = Xp, 
-		delta = delta, removed.sites = which(sites.to.remove))
+
+	list(y = y.wide, Xlam = Xlam, Xgam = Xgam, Xom = Xom, Xp = Xp,
+             Xlam.offset=Xlam.offset, Xgam.offset=Xgam.offset,
+             Xom.offset=Xom.offset, Xp.offset=Xp.offset,
+             delta = delta, removed.sites = which(sites.to.remove))
 })
 
 
-    
 
 
-    
-    
-    
-    
-    
-# UnmarkedFrameGMN    
-	
 
-setMethod("getDesign", "unmarkedFrameG3", 
-    function(umf, formula, na.rm = TRUE) 
+
+
+
+
+
+# UnmarkedFrameGMN
+
+
+setMethod("getDesign", "unmarkedFrameG3",
+    function(umf, formula, na.rm = TRUE)
 {
     ac1 <- as.character(formula)
     ac2 <- as.character(formula[[2]])
@@ -517,14 +553,14 @@ setMethod("getDesign", "unmarkedFrameG3",
     detformula <- as.formula(paste(ac1[1], ac1[3]))
     phiformula <- as.formula(paste(ac2[1], ac2[3]))
     lamformula <- as.formula(formula[[2]][[2]])
-    
+
     detVars <- all.vars(detformula)
-  
+
     M <- numSites(umf)
     T <- umf@numPrimary
     R <- obsNum(umf)
     J <- R/T
-  
+
     ## Compute phi design matrices
     if(is.null(umf@yearlySiteCovs)) {
         yearlySiteCovs <- data.frame(placeHolder = rep(1, M*T))
@@ -540,7 +576,7 @@ setMethod("getDesign", "unmarkedFrameG3",
     Xphi <- model.matrix(phiformula, Xphi.mf)
     Xphi.offset <- as.vector(model.offset(Xphi.mf))
     if(!is.null(Xphi.offset)) Xphi.offset[is.na(Xphi.offset)] <- 0
-  
+
     # Compute site-level design matrix for lambda
     if(is.null(siteCovs(umf))) {
         siteCovs <- data.frame(placeHolder = rep(1, M))
@@ -554,40 +590,43 @@ setMethod("getDesign", "unmarkedFrameG3",
     if(is.null(obsCovs(umf))) {
         obsCovs <- data.frame(placeHolder = rep(1, M*R))
     } else obsCovs <- obsCovs(umf)
-	
+
     # add site and yearlysite covariates, which contain siteCovs
     cnames <- c(colnames(obsCovs), colnames(yearlySiteCovs))
     obsCovs <- cbind(obsCovs, yearlySiteCovs[rep(1:(M*T), each = J),])
     colnames(obsCovs) <- cnames
-	
+
     # add observation number if not present
     if(!("obsNum" %in% names(obsCovs)))
         obsCovs <- cbind(obsCovs, obsNum = as.factor(rep(1:R, M)))
-	
+
     Xdet.mf <- model.frame(detformula, obsCovs, na.action = NULL)
     Xdet <- model.matrix(detformula, Xdet.mf)
     Xdet.offset <- as.vector(model.offset(Xdet.mf))
     if(!is.null(Xdet.offset)) Xdet.offset[is.na(Xdet.offset)] <- 0
-	
+
     if(na.rm)
-        out <- handleNA(umf, Xlam, Xlam.offset, Xphi, Xphi.offset, Xdet, 
+        out <- handleNA(umf, Xlam, Xlam.offset, Xphi, Xphi.offset, Xdet,
             Xdet.offset)
     else
-        out <- list(y=getY(umf), Xlam=Xlam, Xlam.offset = Xlam.offset, 
+        out <- list(y=getY(umf), Xlam=Xlam, Xlam.offset = Xlam.offset,
             Xphi=Xphi, Xphi.offset = Xphi.offset, Xdet=Xdet,
 				    removed.sites=integer(0))
-	
-    return(list(y = out$y, Xlam = out$Xlam, Xphi = out$Xphi, Xdet = out$Xdet, 
-        Xlam.offset = out$Xlam.offset, Xphi.offset = out$Xphi.offset, 
-        Xdet.offset = out$Xdet.offset, removed.sites = out$removed.sites))
+
+    return(list(y = out$y, Xlam = out$Xlam, Xphi = out$Xphi,
+                Xdet = out$Xdet,
+                Xlam.offset = out$Xlam.offset,
+                Xphi.offset = out$Xphi.offset,
+                Xdet.offset = out$Xdet.offset,
+                removed.sites = out$removed.sites))
 })
 
 
 
 
 
-setMethod("handleNA", "unmarkedFrameG3", 
-    function(umf, Xlam, Xlam.offset, Xphi, Xphi.offset, Xdet, Xdet.offset) 
+setMethod("handleNA", "unmarkedFrameG3",
+    function(umf, Xlam, Xlam.offset, Xphi, Xphi.offset, Xdet, Xdet.offset)
 {
 
     obsToY <- obsToY(umf)
@@ -597,13 +636,13 @@ setMethod("handleNA", "unmarkedFrameG3",
     T <- umf@numPrimary
     R <- obsNum(umf)
     J <- numY(umf) / T  # R/T
-	
+
     # treat Xphi and Xlam together
     X <- cbind(Xphi, Xlam[rep(1:M, each = T), ])
 
     X.na <- is.na(X)
     X.long.na <- X.na[rep(1:(M*T), each = J),]
-	
+
     Xdet.long.na <- apply(Xdet, 2, function(x) {
         x.mat <- matrix(x, M, R, byrow = TRUE)
         x.mat <- is.na(x.mat)
@@ -613,37 +652,38 @@ setMethod("handleNA", "unmarkedFrameG3",
         })
 
     Xdet.long.na <- apply(Xdet.long.na, 1, any)
-	
+
     y.long <- as.vector(t(getY(umf)))
     y.long.na <- is.na(y.long)
-	
+
     covs.na <- apply(cbind(X.long.na, Xdet.long.na), 1, any)
-	
+
     ## are any NA in covs not in y already?
     y.new.na <- covs.na & !y.long.na
-	
+
     if(sum(y.new.na) > 0) {
     		y.long[y.new.na] <- NA
     		warning("Some observations have been discarded because correspoding covariates were missing.", call. = FALSE)
 	     }
-	
+
     y <- matrix(y.long, M, numY(umf), byrow = TRUE)
     sites.to.remove <- apply(y, 1, function(x) all(is.na(x)))
-	
+
     num.to.remove <- sum(sites.to.remove)
     if(num.to.remove > 0) {
-    		y <- y[!sites.to.remove,, drop = FALSE]
+        y <- y[!sites.to.remove,, drop = FALSE]
         Xlam <- Xlam[!sites.to.remove,, drop = FALSE]
-    		Xlam.offset <- Xlam.offset[!sites.to.remove]
-    		Xphi <- Xphi[!sites.to.remove[rep(1:M, each = T)],, drop = FALSE]
-    		Xphi.offset <- Xphi.offset[!sites.to.remove[rep(1:M, each = T)]]
-        Xdet <- Xdet[!sites.to.remove[rep(1:M, each = numY(umf))],, drop=FALSE]
+        Xlam.offset <- Xlam.offset[!sites.to.remove]
+        Xphi <- Xphi[!sites.to.remove[rep(1:M, each = T)],, drop = FALSE]
+        Xphi.offset <- Xphi.offset[!sites.to.remove[rep(1:M, each = T)]]
+        Xdet <- Xdet[!sites.to.remove[rep(1:M, each = numY(umf))],,
+                     drop=FALSE]
         Xdet.offset <- Xdet.offset[!sites.to.remove[rep(1:M, each=numY(umf))]]
-    		warning(paste(num.to.remove, 
-            "sites have been discarded because of missing data."), call.=FALSE)
-	     }
-    list(y = y, Xlam = Xlam, Xlam.offset = Xlam.offset, Xphi = Xphi, 
+        warning(paste(num.to.remove,
+                      "sites have been discarded because of missing data."), call.=FALSE)
+    }
+    list(y = y, Xlam = Xlam, Xlam.offset = Xlam.offset, Xphi = Xphi,
         Xphi.offset = Xphi.offset, Xdet = Xdet, Xdet.offset = Xdet.offset,
         removed.sites = which(sites.to.remove))
 })
-  
+
